# antibodyomics

## Backend

I'm using setuptools, but other options were Hatchling, Flit and PDM

https://packaging.python.org/en/latest/tutorials/packaging-projects/


## Action Items

1. I need to add the required packages to `pyproject.toml` 
